@@ -393,7 +393,8 @@ class GeneralSettings(BaseSiteSetting):
         verbose_name=_("From email address"),
         help_text=_(
             "The default email address this site appears to send from. "
-            'For example: "sender@abc.com" or "Sender Name <sender@abc.com>" (without quotes)'
+            'For example: "sender@example.com" or '
+            '"Sender Name <sender@example.com>" (without quotes)'
         ),
         # noqa
     )
